#  tests for bitarray-1.7.1-py39h140841e_1 (this is a generated file);
print('===== testing package: bitarray-1.7.1-py39h140841e_1 =====');
print('running run_test.py');
#  --- run_test.py (begin) ---
import bitarray

assert bitarray.test().wasSuccessful()
#  --- run_test.py (end) ---

print('===== bitarray-1.7.1-py39h140841e_1 OK =====');
print("import: 'bitarray'")
import bitarray

